import express from "express";
import { AppDataSource } from "./data-source";
import UserRouter from "./routers/user";
import bodyParser from "body-parser";
import cookieParser from 'cookie-parser';
import PostRouter from "./routers/post";
import session from "express-session";

const app = express();

app.use(express.json({limit: "200mb"}));
app.use(express.urlencoded({ extended: false, limit: "200mb", parameterLimit: 100000  }));
app.use(cookieParser());
app.use(session({
    secret: process.env.SESSION_SECRET,
    resave: false,
    saveUninitialized: false,
}));

AppDataSource.initialize().then(() => {
    app.use('/api/v1/user/', UserRouter);
    app.use('/api/v1/post/', PostRouter);

    const port = process.env.APP_PORT;
    app.listen(port, () => {
        console.log(`Listening on port ${port}`)
    });
});